@@ -156,7 +156,7 @@ struct ndis_auth_req {
 
 struct ndis_bssid_info {
 	mac_address bssid;
-	UCHAR pmkid[16];
+	ndis_pmkid_vavlue pmkid;
 };
 
 struct ndis_pmkid {
@@ -165,27 +165,34 @@ struct ndis_pmkid {
 	struct ndis_bssid_info bssid_info[1];
 };
 
-int add_wep_key(struct wrap_ndis_device *wnd, char *key, int key_len,
+int add_wep_key(struct ndis_device *wnd, char *key, int key_len,
 		int index);
-int set_essid(struct wrap_ndis_device *wnd, const char *ssid, int ssid_len);
-int set_infra_mode(struct wrap_ndis_device *wnd,
-		   enum network_infrastructure mode);
-int get_ap_address(struct wrap_ndis_device *wnd, mac_address mac);
-int set_auth_mode(struct wrap_ndis_device *wnd, ULONG auth_mode);
-int set_encr_mode(struct wrap_ndis_device *wnd, ULONG encr_mode);
-int get_auth_mode(struct wrap_ndis_device *wnd);
-int get_encr_mode(struct wrap_ndis_device *wnd);
-int set_priv_filter(struct wrap_ndis_device *wnd, int flags);
-int set_scan(struct wrap_ndis_device *wnd);
-NDIS_STATUS disassociate(struct wrap_ndis_device *wnd, int reset_ssid);
+int set_essid(struct ndis_device *wnd, const char *ssid, int ssid_len);
+int set_infra_mode(struct ndis_device *wnd,
+		   enum ndis_infrastructure_mode mode);
+int get_ap_address(struct ndis_device *wnd, mac_address mac);
+int set_ndis_auth_mode(struct ndis_device *wnd, ULONG auth_mode);
+int set_iw_auth_mode(struct ndis_device *wnd, int wpa_version,
+		     int auth_80211_alg);
+int set_auth_mode(struct ndis_device *wnd);
+int set_ndis_encr_mode(struct ndis_device *wnd, int cipher_pairwise,
+		       int cipher_groupwise);
+int get_ndis_encr_mode(struct ndis_device *wnd);
+int set_encr_mode(struct ndis_device *wnd);
+int set_iw_encr_mode(struct ndis_device *wnd, int cipher_pairwise,
+		     int cipher_groupwise);
+int get_ndis_auth_mode(struct ndis_device *wnd);
+int set_priv_filter(struct ndis_device *wnd);
+int set_scan(struct ndis_device *wnd);
+NDIS_STATUS disassociate(struct ndis_device *wnd, int reset_ssid);
+void set_default_iw_params(struct ndis_device *wnd);
+extern const struct iw_handler_def ndis_handler_def;
 
 #define PRIV_RESET	 		SIOCIWFIRSTPRIV+16
 #define PRIV_POWER_PROFILE	 	SIOCIWFIRSTPRIV+17
 #define PRIV_NETWORK_TYPE	 	SIOCIWFIRSTPRIV+18
-#define PRIV_USB_RESET	 		SIOCIWFIRSTPRIV+19
+#define PRIV_DEAUTHENTICATE 		SIOCIWFIRSTPRIV+19
 #define PRIV_MEDIA_STREAM_MODE 		SIOCIWFIRSTPRIV+20
-#define PRIV_SET_ENCR_MODE		SIOCIWFIRSTPRIV+21
-#define PRIV_SET_AUTH_MODE		SIOCIWFIRSTPRIV+22
 #define PRIV_RELOAD_DEFAULTS		SIOCIWFIRSTPRIV+23
 
 #define RSN_INFO_ELEM		0x30
@@ -198,78 +205,4 @@ typedef enum { CIPHER_NONE, CIPHER_WEP40, CIPHER_TKIP, CIPHER_CCMP,
 typedef enum { KEY_MGMT_802_1X, KEY_MGMT_PSK, KEY_MGMT_NONE,
 	       KEY_MGMT_802_1X_NO_WPA, KEY_MGMT_WPA_NONE } wpa_key_mgmt;
 
-#if WIRELESS_EXT <= 17
-/* WPA support through 'ndiswrapper' driver interface */
-
-#define AUTH_ALG_OPEN_SYSTEM	0x01
-#define AUTH_ALG_SHARED_KEY	0x02
-#define AUTH_ALG_LEAP		0x04
-
-#define IEEE80211_MODE_INFRA	0
-#define IEEE80211_MODE_IBSS	1
-
-struct wpa_key {
-	wpa_alg alg;
-	u8 *addr;
-	int key_index;
-	int set_tx;
-	u8 *seq;
-	size_t seq_len;
-	u8 *key;
-	size_t key_len;
-};
-
-struct wpa_assoc_info {
-	const u8 *bssid;
-	const u8 *ssid;
-	size_t ssid_len;
-	int freq;
-	const u8 *wpa_ie;
-	size_t wpa_ie_len;
-	wpa_cipher pairwise_suite;
-	wpa_cipher group_suite;
-	wpa_key_mgmt key_mgmt_suite;
-	int auth_alg;
-	int mode;
-};
-
-struct wpa_driver_capa {
-#define WPA_DRIVER_CAPA_KEY_MGMT_WPA        0x00000001
-#define WPA_DRIVER_CAPA_KEY_MGMT_WPA2       0x00000002
-#define WPA_DRIVER_CAPA_KEY_MGMT_WPA_PSK    0x00000004
-#define WPA_DRIVER_CAPA_KEY_MGMT_WPA2_PSK   0x00000008
-#define WPA_DRIVER_CAPA_KEY_MGMT_WPA_NONE   0x00000010
-	unsigned int key_mgmt;
-
-#define WPA_DRIVER_CAPA_ENC_WEP40   0x00000001
-#define WPA_DRIVER_CAPA_ENC_WEP104  0x00000002
-#define WPA_DRIVER_CAPA_ENC_TKIP    0x00000004
-#define WPA_DRIVER_CAPA_ENC_CCMP    0x00000008
-	unsigned int enc;
-
-#define WPA_DRIVER_AUTH_OPEN        0x00000001
-#define WPA_DRIVER_AUTH_SHARED      0x00000002
-#define WPA_DRIVER_AUTH_LEAP        0x00000004
-	unsigned int auth;
-
-/* Driver generated WPA/RSN IE */
-#define WPA_DRIVER_FLAGS_DRIVER_IE  0x00000001
-#define WPA_DRIVER_FLAGS_SET_KEYS_AFTER_ASSOC 0x00000002
-	unsigned int flags;
-};
-
-#define WPA_SET_WPA 			SIOCIWFIRSTPRIV+1
-#define WPA_SET_KEY 			SIOCIWFIRSTPRIV+2
-#define WPA_ASSOCIATE		 	SIOCIWFIRSTPRIV+3
-#define WPA_DISASSOCIATE 		SIOCIWFIRSTPRIV+4
-#define WPA_DROP_UNENCRYPTED 		SIOCIWFIRSTPRIV+5
-#define WPA_SET_COUNTERMEASURES 	SIOCIWFIRSTPRIV+6
-#define WPA_DEAUTHENTICATE	 	SIOCIWFIRSTPRIV+7
-#define WPA_SET_AUTH_ALG	 	SIOCIWFIRSTPRIV+8
-#define WPA_INIT			SIOCIWFIRSTPRIV+9
-#define WPA_DEINIT			SIOCIWFIRSTPRIV+10
-#define WPA_GET_CAPA			SIOCIWFIRSTPRIV+11
-
-#endif
-
 #endif // IW_NDIS_H
