@@ -750,8 +750,13 @@ struct wrap_device *get_wrap_device(void *dev, int bus)
 }
 
 /* called with loader_mutex is down */
+#ifdef HAVE_UNLOCKED_IOCTL
+static long wrapper_ioctl(struct file *file,
+			 unsigned int cmd, unsigned long arg)
+#else
 static int wrapper_ioctl(struct inode *inode, struct file *file,
 			 unsigned int cmd, unsigned long arg)
+#endif
 {
 	struct load_driver *load_driver;
 	struct load_device load_device;
@@ -831,7 +836,12 @@ static int wrapper_ioctl_release(struct inode *inode, struct file *file)
 
 static struct file_operations wrapper_fops = {
 	.owner          = THIS_MODULE,
+
+#ifdef HAVE_UNLOCKED_IOCTL
+	.unlocked_ioctl	= wrapper_ioctl,
+#else
 	.ioctl		= wrapper_ioctl,
+#endif
 	.release	= wrapper_ioctl_release,
 };
 
@@ -847,7 +857,7 @@ int loader_init(void)
 
 	InitializeListHead(&wrap_drivers);
 	InitializeListHead(&wrap_devices);
-	init_MUTEX(&loader_mutex);
+	sema_init(&loader_mutex, 1);
 	init_completion(&loader_complete);
 	if ((err = misc_register(&wrapper_misc)) < 0 ) {
 		ERROR("couldn't register module (%d)", err);
