@@ -324,6 +324,12 @@ typedef u32 pm_message_t;
 	kmem_cache_create(name, size, align, flags, NULL)
 #endif
 
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2,6,34)
+#define netdev_mc_count(dev) ((dev)->mc_count)
+#define usb_alloc_coherent(dev, size, mem_flags, dma) (usb_buffer_alloc((dev), (size), (mem_flags), (dma)))
+#define usb_free_coherent(dev, size, addr, dma) (usb_buffer_free((dev), (size), (addr), (dma)))
+#endif
+
 #include "winnt_types.h"
 #include "ndiswrapper.h"
 #include "pe_linker.h"
@@ -875,8 +881,7 @@ static inline struct nt_slist *PopEntrySList(nt_slist_header *head,
 #define u64_low_32(x) ((u32)x)
 #define u64_high_32(x) ((u32)(x >> 32))
 
-#if LINUX_VERSION_CODE < KERNEL_VERSION(2,6,31)
-static inline u64 cmpxchg8b(volatile u64 *ptr, u64 old, u64 new)
+static inline u64 nt_cmpxchg8b(volatile u64 *ptr, u64 old, u64 new)
 {
 	u64 prev;
 
@@ -887,7 +892,6 @@ static inline u64 cmpxchg8b(volatile u64 *ptr, u64 old, u64 new)
 		: "A" (old), "b" (u64_low_32(new)), "c" (u64_high_32(new)));
 	return prev;
 }
-#endif
 
 /* slist routines below update slist atomically - no need for
  * spinlocks */
@@ -902,7 +906,7 @@ static inline struct nt_slist *PushEntrySList(nt_slist_header *head,
 		entry->next = old.next;
 		new.next = entry;
 		new.depth = old.depth + 1;
-	} while (cmpxchg8b(&head->align, old.align, new.align) != old.align);
+	} while (nt_cmpxchg8b(&head->align, old.align, new.align) != old.align);
 	TRACE4("%p, %p, %p", head, entry, old.next);
 	return old.next;
 }
@@ -919,7 +923,7 @@ static inline struct nt_slist *PopEntrySList(nt_slist_header *head,
 			break;
 		new.next = entry->next;
 		new.depth = old.depth - 1;
-	} while (cmpxchg8b(&head->align, old.align, new.align) != old.align);
+	} while (nt_cmpxchg8b(&head->align, old.align, new.align) != old.align);
 	TRACE4("%p, %p", head, entry);
 	return entry;
 }
